/*****************************************************************************
 *
 *  kv5500_phonebook - read a phonebook from kv5500 like phone.
 *
 * Copyright (c) 2006 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include "kv5500_phonebook.hpp"

using namespace KV5500;

void PrintNumber(const std::vector<std::string>& num)
{
    if(num.empty())
        return;

    unsigned int count = 1;
    for(std::vector<std::string>::const_iterator i = num.begin();
        i != num.end();
        ++i, ++count) {

        printf(" Tel %d : %s\n", count, i->c_str());
    }
}

void PrintPhonebook()
{
    try {

        std::vector<PhonebookData> thisBook;

        GetPhonebook(thisBook);

        if(thisBook.empty()) {

            printf("Nothing\n");

            return;
        }

        const unsigned int total = thisBook.size();
        unsigned int count = 1;
        for(std::vector<PhonebookData>::const_iterator i = thisBook.begin();
            i != thisBook.end();
            ++i, ++count) {

            printf("-------------------------------------------%03d/%03d---\n", count, total);
            printf(" Name  : %s\n", i->GetName().c_str());
            PrintNumber(i->GetNumber());
        }

    } catch(std::exception& e) {

        printf("%s\n", e.what());

        std::exit(1);        
    }
}

int main()
{
    PrintPhonebook();

    return 0;
}
